@@ -43,12 +43,14 @@ class ProjectsUpdateTask(object):
                 err = sys.exc_info()[1]
                 if err.args[0] != 2006:  # MYSQL Has gone Away
                     raise err
+                logging.exception(exc_info=err)
 
                 self.db.reconnect()
             finally:
                 tries += 1
 
         if db_projects is None:
+            logging.warn("Could not retrieve information from sentry's database because MySQL Server was unavailable")
             return
 
         for project in db_projects:
